/**
 * Provides a read-only Map interface that aggregates results from multiple results in O(n)
 */
export declare class AggregateMap<K, V> implements ReadonlyMap<K, V> {
    private maps;
    /**
     * @param maps An Iterable that when iterated provides the Maps to aggregate results from
     */
    constructor(maps: Iterable<ReadonlyMap<K, V>>);
    /**
     * Returns the cumulative size of all Maps
     */
    readonly size: number;
    /**
     * Looks up a key in all Maps and returns the first result
     */
    get(key: K): V | undefined;
    /**
     * Checks if a key exists in any Map
     */
    has(key: K): boolean;
    /**
     * Iterates over all keys from all Maps
     */
    keys(): IterableIterator<K>;
    /**
     * Iterates over all values from all Maps
     */
    values(): IterableIterator<V>;
    /**
     * Iterates over all entries from all Maps
     */
    entries(): IterableIterator<[K, V]>;
    /**
     * Iterates over all entries from all Maps
     */
    [Symbol.iterator](): IterableIterator<[K, V]>;
    /**
     * Calls a callback function for all items in all Maps
     */
    forEach(callbackfn: (value: V, key: K, map: ReadonlyMap<K, V>) => void, thisArg?: any): void;
}
export default AggregateMap;
